sparky-polkit for Debian
-----------------------

<Possible notes regarding this package - if none, delete this file.>

 -- pavroo <pavroo@onet.eu>  Mon, 22 Dec 2025 16:02:33 +0000
